@@ -1,4 +1,5 @@
 """pytest plugin for VCS Repository testing and management."""
+
 import functools
 import getpass
 import pathlib
@@ -22,21 +23,24 @@ if TYPE_CHECKING:
 class MaxUniqueRepoAttemptsExceeded(exc.LibVCSException):
     """Raised when exceeded threshold of attempts to find a unique repo destination."""
 
-    def __init__(self, attempts: int, *args: object):
+    def __init__(self, attempts: int, *args: object) -> None:
         """Raise LibVCSException exception with message including attempts tried."""
         return super().__init__(
-            f"Could not find unused repo destination (attempts: {attempts})"
+            f"Could not find unused repo destination (attempts: {attempts})",
         )
 
 
 skip_if_git_missing = pytest.mark.skipif(
-    not shutil.which("git"), reason="git is not available"
+    not shutil.which("git"),
+    reason="git is not available",
 )
 skip_if_svn_missing = pytest.mark.skipif(
-    not shutil.which("svn"), reason="svn is not available"
+    not shutil.which("svn"),
+    reason="svn is not available",
 )
 skip_if_hg_missing = pytest.mark.skipif(
-    not shutil.which("hg"), reason="hg is not available"
+    not shutil.which("hg"),
+    reason="hg is not available",
 )
 
 
@@ -44,7 +48,8 @@ class RandomStrSequence:
     """Create a random string sequence."""
 
     def __init__(
-        self, characters: str = "abcdefghijklmnopqrstuvwxyz0123456789_"
+        self,
+        characters: str = "abcdefghijklmnopqrstuvwxyz0123456789_",
     ) -> None:
         self.characters: str = characters
 
@@ -68,12 +73,10 @@ def pytest_ignore_collect(collection_path: pathlib.Path, config: pytest.Config)
         return True
     if not shutil.which("git") and "git" in str(collection_path):
         return True
-    if not shutil.which("hg") and any(
-        needle in str(collection_path) for needle in ["hg", "mercurial"]
-    ):
-        return True
-
-    return False
+    return bool(
+        not shutil.which("hg")
+        and any(needle in str(collection_path) for needle in ["hg", "mercurial"]),
+    )
 
 
 @pytest.fixture(scope="session")
@@ -96,7 +99,7 @@ def user_path(home_path: pathlib.Path, home_user_name: str) -> pathlib.Path:
     return p
 
 
-@pytest.fixture(scope="function")
+@pytest.fixture()
 def set_home(
     monkeypatch: pytest.MonkeyPatch,
     user_path: pathlib.Path,
@@ -105,7 +108,7 @@ def set_home(
     monkeypatch.setenv("HOME", str(user_path))
 
 
-@pytest.fixture
+@pytest.fixture()
 @skip_if_git_missing
 def gitconfig(user_path: pathlib.Path, set_home: pathlib.Path) -> pathlib.Path:
     """Return git configuration, pytest fixture."""
@@ -119,7 +122,7 @@ def gitconfig(user_path: pathlib.Path, set_home: pathlib.Path) -> pathlib.Path:
     name = {getpass.getuser()}
   [color]
     diff = auto
-    """
+    """,
         ),
         encoding="utf-8",
     )
@@ -132,7 +135,7 @@ def gitconfig(user_path: pathlib.Path, set_home: pathlib.Path) -> pathlib.Path:
             "--show-origin",
             "--get",
             "user.email",
-        ]
+        ],
     )
     assert str(gitconfig) in used_config_file_output
     assert user_email in output, "Should use our fixture config and home directory"
@@ -140,7 +143,7 @@ def gitconfig(user_path: pathlib.Path, set_home: pathlib.Path) -> pathlib.Path:
     return gitconfig
 
 
-@pytest.fixture
+@pytest.fixture()
 @skip_if_hg_missing
 def hgconfig(user_path: pathlib.Path, set_home: pathlib.Path) -> pathlib.Path:
     """Return Mercurial configuration, pytest fixture."""
@@ -154,41 +157,43 @@ def hgconfig(user_path: pathlib.Path, set_home: pathlib.Path) -> pathlib.Path:
 
         [trusted]
         users = {getpass.getuser()}
-    """
+    """,
         ),
         encoding="utf-8",
     )
     return hgrc
 
 
-@pytest.fixture(scope="function")
+@pytest.fixture()
 def projects_path(
-    user_path: pathlib.Path, request: pytest.FixtureRequest
+    user_path: pathlib.Path,
+    request: pytest.FixtureRequest,
 ) -> pathlib.Path:
     """User's local checkouts and clones. Emphemeral directory."""
-    dir = user_path / "projects"
-    dir.mkdir(exist_ok=True)
+    path = user_path / "projects"
+    path.mkdir(exist_ok=True)
 
     def clean() -> None:
-        shutil.rmtree(dir)
+        shutil.rmtree(path)
 
     request.addfinalizer(clean)
-    return dir
+    return path
 
 
-@pytest.fixture(scope="function")
+@pytest.fixture()
 def remote_repos_path(
-    user_path: pathlib.Path, request: pytest.FixtureRequest
+    user_path: pathlib.Path,
+    request: pytest.FixtureRequest,
 ) -> pathlib.Path:
     """System's remote (file-based) repos to clone andpush to. Emphemeral directory."""
-    dir = user_path / "remote_repos"
-    dir.mkdir(exist_ok=True)
+    path = user_path / "remote_repos"
+    path.mkdir(exist_ok=True)
 
     def clean() -> None:
-        shutil.rmtree(dir)
+        shutil.rmtree(path)
 
     request.addfinalizer(clean)
-    return dir
+    return path
 
 
 def unique_repo_name(remote_repos_path: pathlib.Path, max_retries: int = 15) -> str:
@@ -250,7 +255,7 @@ def _create_git_remote_repo(
     return remote_repo_path
 
 
-@pytest.fixture
+@pytest.fixture()
 @skip_if_git_missing
 def create_git_remote_repo(
     remote_repos_path: pathlib.Path,
@@ -283,8 +288,7 @@ def git_remote_repo_single_commit_post_init(remote_repo_path: pathlib.Path) -> N
     run(["git", "commit", "-m", "test file for dummyrepo"], cwd=remote_repo_path)
 
 
-@pytest.fixture
-@pytest.mark.usefixtures("gitconfig", "set_home")
+@pytest.fixture()
 @skip_if_git_missing
 def git_remote_repo(remote_repos_path: pathlib.Path) -> pathlib.Path:
     """Pre-made git repo w/ 1 commit, used as a file:// remote to clone and push to."""
@@ -330,13 +334,13 @@ def svn_remote_repo_single_commit_post_init(remote_repo_path: pathlib.Path) -> N
                 str(remote_repo_path),
                 "<",
                 str(repo_dumpfile),
-            ]
+            ],
         ),
         shell=True,
     )
 
 
-@pytest.fixture
+@pytest.fixture()
 @skip_if_svn_missing
 def create_svn_remote_repo(
     remote_repos_path: pathlib.Path,
@@ -361,18 +365,16 @@ def create_svn_remote_repo(
     return fn
 
 
-@pytest.fixture
+@pytest.fixture()
 @skip_if_svn_missing
 def svn_remote_repo(remote_repos_path: pathlib.Path) -> pathlib.Path:
     """Pre-made. Local file:// based SVN server."""
-    remote_repo_path = _create_svn_remote_repo(
+    return _create_svn_remote_repo(
         remote_repos_path=remote_repos_path,
         remote_repo_name="svn_server_dir",
         remote_repo_post_init=None,
     )
 
-    return remote_repo_path
-
 
 def _create_hg_remote_repo(
     remote_repos_path: pathlib.Path,
@@ -401,7 +403,7 @@ def hg_remote_repo_single_commit_post_init(remote_repo_path: pathlib.Path) -> No
     run(["hg", "commit", "-m", "test file for hg repo"], cwd=remote_repo_path)
 
 
-@pytest.fixture
+@pytest.fixture()
 @skip_if_hg_missing
 def create_hg_remote_repo(
     remote_repos_path: pathlib.Path,
@@ -428,10 +430,11 @@ def create_hg_remote_repo(
     return fn
 
 
-@pytest.fixture
+@pytest.fixture()
 @skip_if_hg_missing
 def hg_remote_repo(
-    remote_repos_path: pathlib.Path, hgconfig: pathlib.Path
+    remote_repos_path: pathlib.Path,
+    hgconfig: pathlib.Path,
 ) -> pathlib.Path:
     """Pre-made, file-based repo for push and pull."""
     return _create_hg_remote_repo(
@@ -441,47 +444,47 @@ def hg_remote_repo(
     )
 
 
-@pytest.fixture
+@pytest.fixture()
 def git_repo(projects_path: pathlib.Path, git_remote_repo: pathlib.Path) -> GitSync:
     """Pre-made git clone of remote repo checked out to user's projects dir."""
     git_repo = GitSync(
         url=f"file://{git_remote_repo}",
-        dir=str(projects_path / "git_repo"),
+        path=str(projects_path / "git_repo"),
         remotes={
             "origin": GitRemote(
                 name="origin",
                 push_url=f"file://{git_remote_repo}",
                 fetch_url=f"file://{git_remote_repo}",
-            )
+            ),
         },
     )
     git_repo.obtain()
     return git_repo
 
 
-@pytest.fixture
+@pytest.fixture()
 def hg_repo(projects_path: pathlib.Path, hg_remote_repo: pathlib.Path) -> HgSync:
     """Pre-made hg clone of remote repo checked out to user's projects dir."""
     hg_repo = HgSync(
         url=f"file://{hg_remote_repo}",
-        dir=str(projects_path / "hg_repo"),
+        path=str(projects_path / "hg_repo"),
     )
     hg_repo.obtain()
     return hg_repo
 
 
-@pytest.fixture
+@pytest.fixture()
 def svn_repo(projects_path: pathlib.Path, svn_remote_repo: pathlib.Path) -> SvnSync:
     """Pre-made svn clone of remote repo checked out to user's projects dir."""
     svn_repo = SvnSync(
         url=f"file://{svn_remote_repo}",
-        dir=str(projects_path / "svn_repo"),
+        path=str(projects_path / "svn_repo"),
     )
     svn_repo.obtain()
     return svn_repo
 
 
-@pytest.fixture
+@pytest.fixture()
 def add_doctest_fixtures(
     request: pytest.FixtureRequest,
     doctest_namespace: dict[str, Any],
